.. _recipe_asr.exchange:

asr.exchange
============


.. contents:: Contents
   :local:

Summary
-------

This is the documentation for :py:mod:`asr.exchange`-recipe.
This recipe is comprised of 2 steps, namely:

  - :py:func:`asr.exchange.calculate`
  - :py:func:`asr.exchange.main`

Run this recipe through the CLI interface

.. code-block:: console

   $ asr run asr.exchange

or as a python module

.. code-block:: console

   $ python -m asr.exchange


Steps
-----


asr.exchange@calculate
^^^^^^^^^^^^^^^^^^^^^^
.. autofunction:: asr.exchange.calculate
   

asr.exchange
^^^^^^^^^^^^
.. autofunction:: asr.exchange.main
   